api

package
v0.0.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// PluginLaunchedByEngineVar is used to inform engine-launched plugins about their name.
	PluginLaunchedByEngineVar = "DOCKER_SECRETS_ENGINE_PLUGIN_LAUNCH_CFG"
	// DefaultPluginRegistrationTimeout is the default timeout for plugin registration.
	DefaultPluginRegistrationTimeout = 5 * time.Second
	// DefaultPluginRequestTimeout is the default timeout for plugins to handle a request.
	DefaultPluginRequestTimeout = 2 * time.Second
)

Variables

var (
	ErrEmptyVersion = errors.New("empty version")
	ErrVPrefix      = errors.New("missing version prefix")
)
var ErrEmptyName = errors.New("empty name")

Functions

func DefaultSocketPath

func DefaultSocketPath() string

Types

type Name added in v0.0.6

type Name interface {
	String() string
}

func MustNewName added in v0.0.6

func MustNewName(s string) Name

MustNewName creates a new Name as NewName does, but panics when a validation error occurs.

func NewName added in v0.0.6

func NewName(s string) (Name, error)

NewName creates a new Name from a string If a validation error occurs, it returns nil and the error.

type Version added in v0.0.6

type Version interface {
	String() string
}

func MustNewVersion added in v0.0.6

func MustNewVersion(s string) Version

MustNewVersion creates a new Version as NewVersion does, but panics when a validation error occurs.

func NewVersion added in v0.0.6

func NewVersion(s string) (Version, error)

NewVersion creates a new Version from a string If a validation error occurs, it returns nil and the error.

Directories

Path Synopsis
resolver
v1

Jump to