logging

package
v0.0.24-do.not.use Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: Apache-2.0 Imports: 8 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithLogger

func WithLogger(ctx context.Context, logger Logger) context.Context

WithLogger returns a new context with the provided logger.

Types

type Logger

type Logger interface {
	Printf(format string, v ...interface{})
	Warnf(format string, v ...interface{})
	Errorf(format string, v ...interface{})
}

func FromContext

func FromContext(ctx context.Context) (Logger, error)

FromContext retrieves the current logger from the context. If no logger is available, a new default logger gets returned.

func NewDefaultLogger

func NewDefaultLogger(prefix string, options ...Option) Logger

type Option

type Option func(l *defaultLogger)

func WithOut

func WithOut(out io.Writer) Option

Jump to