testhelper

package
v0.0.30-do.not.use Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FilterMetrics

func FilterMetrics(rm metricdata.ResourceMetrics, name string) []metricdata.Metrics

func RandomShortSocketName

func RandomShortSocketName() string

RandomShortSocketName creates a socket name string that avoids common pitfalls in tests. There are a bunch of opposing problems in unit tests with sockets: Ideally, we'd like to use t.TmpDir+something.sock -> too long socket name We can't just use local short file name -> clashes when running tests in parallel We can't use t.ChDir + short name -> t.ChDir does not allow t.Parallel -> we use a short local but randomized socket path

func SetupTelemetry

func SetupTelemetry(t *testing.T) (*tracetest.SpanRecorder, *metric.ManualReader)

func TestLogger

func TestLogger(t *testing.T) logging.Logger

func TestLoggerCtx

func TestLoggerCtx(t *testing.T) context.Context

func WaitForClosedWithTimeout

func WaitForClosedWithTimeout(in <-chan struct{}) error

func WaitForErrorWithTimeout

func WaitForErrorWithTimeout(in <-chan error) error

func WaitForWithExplicitTimeoutV

func WaitForWithExplicitTimeoutV[T any](ch <-chan T, timeout time.Duration) (T, error)

func WaitForWithTimeoutV

func WaitForWithTimeoutV[T any](ch <-chan T) (T, error)

Types

type MockResolver

type MockResolver struct {
	Store map[secrets.ID]string
}

func (MockResolver) GetSecrets

func (m MockResolver) GetSecrets(_ context.Context, pattern secrets.Pattern) ([]secrets.Envelope, error)

type TestTracker

type TestTracker interface {
	telemetry.Tracker
	GetQueue() []any
}

func NewTestTracker

func NewTestTracker() TestTracker

Jump to