Documentation
¶
Index ¶
Constants ¶
const ( // PluginLaunchedByEngineVar is used to inform engine-launched plugins about their name. PluginLaunchedByEngineVar = "DOCKER_SECRETS_ENGINE_PLUGIN_LAUNCH_CFG" // DefaultPluginRegistrationTimeout is the default timeout for plugin registration. DefaultPluginRegistrationTimeout = 5 * time.Second // DefaultPluginRequestTimeout is the default timeout for plugins to handle a request. DefaultPluginRequestTimeout = 2 * time.Second )
Variables ¶
var ( ErrEmptyVersion = errors.New("empty version") ErrVPrefix = errors.New("missing version prefix") )
var ErrEmptyName = errors.New("empty name")
Functions ¶
func DefaultSocketPath ¶
func DefaultSocketPath() string
Types ¶
type Name ¶ added in v0.0.6
type Name interface {
String() string
}
func MustNewName ¶ added in v0.0.6
MustNewName creates a new Name as NewName does, but panics when a validation error occurs.
type Version ¶ added in v0.0.6
type Version interface {
String() string
}
func MustNewVersion ¶ added in v0.0.6
MustNewVersion creates a new Version as NewVersion does, but panics when a validation error occurs.
Click to show internal directories.
Click to hide internal directories.